==> telepathy-mission-control_4.60.orig.tar.gz: telepathy-mission-control-4.60/libmissioncontrol/mc-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "mc-enum-types.h"
#define g_intern_static_string(s) (s)

/* enumerations from "mission-control.h" */
GType
m_cerror_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_DISCONNECTED_ERROR, "MC_DISCONNECTED_ERROR", "disconnected-error" },
      { MC_INVALID_HANDLE_ERROR, "MC_INVALID_HANDLE_ERROR", "invalid-handle-error" },
      { MC_NO_MATCHING_CONNECTION_ERROR, "MC_NO_MATCHING_CONNECTION_ERROR", "no-matching-connection-error" },
      { MC_INVALID_ACCOUNT_ERROR, "MC_INVALID_ACCOUNT_ERROR", "invalid-account-error" },
      { MC_PRESENCE_FAILURE_ERROR, "MC_PRESENCE_FAILURE_ERROR", "presence-failure-error" },
      { MC_NO_ACCOUNTS_ERROR, "MC_NO_ACCOUNTS_ERROR", "no-accounts-error" },
      { MC_NETWORK_ERROR, "MC_NETWORK_ERROR", "network-error" },
      { MC_CONTACT_DOES_NOT_SUPPORT_VOICE_ERROR, "MC_CONTACT_DOES_NOT_SUPPORT_VOICE_ERROR", "contact-does-not-support-voice-error" },
      { MC_LOWMEM_ERROR, "MC_LOWMEM_ERROR", "lowmem-error" },
      { MC_CHANNEL_REQUEST_GENERIC_ERROR, "MC_CHANNEL_REQUEST_GENERIC_ERROR", "channel-request-generic-error" },
      { MC_CHANNEL_BANNED_ERROR, "MC_CHANNEL_BANNED_ERROR", "channel-banned-error" },
      { MC_CHANNEL_FULL_ERROR, "MC_CHANNEL_FULL_ERROR", "channel-full-error" },
      { MC_CHANNEL_INVITE_ONLY_ERROR, "MC_CHANNEL_INVITE_ONLY_ERROR", "channel-invite-only-error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("MCError"), values);
  }
  return etype;
}
GType
mc_presence_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_PRESENCE_UNSET, "MC_PRESENCE_UNSET", "unset" },
      { MC_PRESENCE_OFFLINE, "MC_PRESENCE_OFFLINE", "offline" },
      { MC_PRESENCE_AVAILABLE, "MC_PRESENCE_AVAILABLE", "available" },
      { MC_PRESENCE_AWAY, "MC_PRESENCE_AWAY", "away" },
      { MC_PRESENCE_EXTENDED_AWAY, "MC_PRESENCE_EXTENDED_AWAY", "extended-away" },
      { MC_PRESENCE_HIDDEN, "MC_PRESENCE_HIDDEN", "hidden" },
      { MC_PRESENCE_DO_NOT_DISTURB, "MC_PRESENCE_DO_NOT_DISTURB", "do-not-disturb" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("McPresence"), values);
  }
  return etype;
}
GType
mc_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_STATUS_DISCONNECTED, "MC_STATUS_DISCONNECTED", "disconnected" },
      { MC_STATUS_CONNECTING, "MC_STATUS_CONNECTING", "connecting" },
      { MC_STATUS_CONNECTED, "MC_STATUS_CONNECTED", "connected" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("McStatus"), values);
  }
  return etype;
}
GType
mc_filter_priority_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_FILTER_PRIORITY_CRITICAL, "MC_FILTER_PRIORITY_CRITICAL", "critical" },
      { MC_FILTER_PRIORITY_SYSTEM, "MC_FILTER_PRIORITY_SYSTEM", "system" },
      { MC_FILTER_PRIORITY_NOTICE, "MC_FILTER_PRIORITY_NOTICE", "notice" },
      { MC_FILTER_PRIORITY_DIALOG, "MC_FILTER_PRIORITY_DIALOG", "dialog" },
      { MC_FILTER_PRIORITY_MONITOR, "MC_FILTER_PRIORITY_MONITOR", "monitor" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("McFilterPriority"), values);
  }
  return etype;
}
GType
mc_filter_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { MC_FILTER_FLAG_INCOMING, "MC_FILTER_FLAG_INCOMING", "incoming" },
      { MC_FILTER_FLAG_OUTCOMING, "MC_FILTER_FLAG_OUTCOMING", "outcoming" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static (g_intern_static_string ("McFilterFlag"), values);
  }
  return etype;
}

#define __MC_ENUM_TYPES_C__

/* Generated data ends here */

==> telepathy-mission-control_4.67.orig.tar.gz: telepathy-mission-control-4.67/libmissioncontrol/mc-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "mc-enum-types.h"
#define g_intern_static_string(s) (s)

/* enumerations from "mission-control.h" */
GType
m_cerror_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_DISCONNECTED_ERROR, "MC_DISCONNECTED_ERROR", "disconnected-error" },
      { MC_INVALID_HANDLE_ERROR, "MC_INVALID_HANDLE_ERROR", "invalid-handle-error" },
      { MC_NO_MATCHING_CONNECTION_ERROR, "MC_NO_MATCHING_CONNECTION_ERROR", "no-matching-connection-error" },
      { MC_INVALID_ACCOUNT_ERROR, "MC_INVALID_ACCOUNT_ERROR", "invalid-account-error" },
      { MC_PRESENCE_FAILURE_ERROR, "MC_PRESENCE_FAILURE_ERROR", "presence-failure-error" },
      { MC_NO_ACCOUNTS_ERROR, "MC_NO_ACCOUNTS_ERROR", "no-accounts-error" },
      { MC_NETWORK_ERROR, "MC_NETWORK_ERROR", "network-error" },
      { MC_CONTACT_DOES_NOT_SUPPORT_VOICE_ERROR, "MC_CONTACT_DOES_NOT_SUPPORT_VOICE_ERROR", "contact-does-not-support-voice-error" },
      { MC_LOWMEM_ERROR, "MC_LOWMEM_ERROR", "lowmem-error" },
      { MC_CHANNEL_REQUEST_GENERIC_ERROR, "MC_CHANNEL_REQUEST_GENERIC_ERROR", "channel-request-generic-error" },
      { MC_CHANNEL_BANNED_ERROR, "MC_CHANNEL_BANNED_ERROR", "channel-banned-error" },
      { MC_CHANNEL_FULL_ERROR, "MC_CHANNEL_FULL_ERROR", "channel-full-error" },
      { MC_CHANNEL_INVITE_ONLY_ERROR, "MC_CHANNEL_INVITE_ONLY_ERROR", "channel-invite-only-error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("MCError"), values);
  }
  return etype;
}
GType
mc_presence_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_PRESENCE_UNSET, "MC_PRESENCE_UNSET", "unset" },
      { MC_PRESENCE_OFFLINE, "MC_PRESENCE_OFFLINE", "offline" },
      { MC_PRESENCE_AVAILABLE, "MC_PRESENCE_AVAILABLE", "available" },
      { MC_PRESENCE_AWAY, "MC_PRESENCE_AWAY", "away" },
      { MC_PRESENCE_EXTENDED_AWAY, "MC_PRESENCE_EXTENDED_AWAY", "extended-away" },
      { MC_PRESENCE_HIDDEN, "MC_PRESENCE_HIDDEN", "hidden" },
      { MC_PRESENCE_DO_NOT_DISTURB, "MC_PRESENCE_DO_NOT_DISTURB", "do-not-disturb" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("McPresence"), values);
  }
  return etype;
}
GType
mc_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_STATUS_DISCONNECTED, "MC_STATUS_DISCONNECTED", "disconnected" },
      { MC_STATUS_CONNECTING, "MC_STATUS_CONNECTING", "connecting" },
      { MC_STATUS_CONNECTED, "MC_STATUS_CONNECTED", "connected" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("McStatus"), values);
  }
  return etype;
}
GType
mc_filter_priority_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { MC_FILTER_PRIORITY_CRITICAL, "MC_FILTER_PRIORITY_CRITICAL", "critical" },
      { MC_FILTER_PRIORITY_SYSTEM, "MC_FILTER_PRIORITY_SYSTEM", "system" },
      { MC_FILTER_PRIORITY_NOTICE, "MC_FILTER_PRIORITY_NOTICE", "notice" },
      { MC_FILTER_PRIORITY_DIALOG, "MC_FILTER_PRIORITY_DIALOG", "dialog" },
      { MC_FILTER_PRIORITY_MONITOR, "MC_FILTER_PRIORITY_MONITOR", "monitor" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("McFilterPriority"), values);
  }
  return etype;
}
GType
mc_filter_flag_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { MC_FILTER_FLAG_INCOMING, "MC_FILTER_FLAG_INCOMING", "incoming" },
      { MC_FILTER_FLAG_OUTGOING, "MC_FILTER_FLAG_OUTGOING", "outgoing" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static (g_intern_static_string ("McFilterFlag"), values);
  }
  return etype;
}

#define __MC_ENUM_TYPES_C__

/* Generated data ends here */
